# mimikit

The MusIc ModelIng toolKIT (MIMIKIT) is a python package that does Machine Learning with music data.

The goal of `mimikit` is to enable you to use referenced and experimental algorithms on data you provide.

`mimikit` is still in early development, details and documentation are on their way.

## License

mimikit is distributed under the terms of the [GNU General Public License v3.0](https://choosealicense.com/licenses/gpl-3.0/)


